Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.tor`` role allows you to manage and configure


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.5``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops-contrib.tor

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
